/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                         **** CIENCIAS NATURALES ****
/*
/*                     Ciclo escolar evaluado: 2009 - 2010
/*_____________________________________________________________________________
/*
/*
/*  PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CIENCIAS NATURALES
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2010_Alum_CN.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2010_Alum_CN.txt
/*         as como el archivo Excale03_2010_Alum_CN.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2010_Alum_CN.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2010_Alum_CN.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 18 DE MAYO DEL 2012
/*
/*  ****************************************************************************/


/*****************************************************************************
/*    ACTUALIZACIN AL 26 DE NOVIEMBRE DEL 2013
/*
/*   - SE CORRIGIERON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE EDADC.
/*   - SE CORRIGIERON LAS ETIQUETAS DE LOS VALORES DE LA VARIABLE EDAD_AC.
/*
/*******************************************************************************/




LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2010_Alum_CN.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     1         = "Urbana Pblica"
                       2         = "Rural Pblica"
                       3         = "Educacin Indgena"
                       4         = "Curso Comunitario"
                       5         = "Privada"
                       6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "UP"      = "Urbano Pblico"
                       "RP"      = "Rural Pblico"
                       "EI"      = "Educacin Indgena"
                       "CC"      = "Cursos Comunitarios"
                       "UPV"     = "Privados"
                       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE sexoF       1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
     VALUE edadF       99        = "Respuesta omitida";
     VALUE edadcF      1         = "Ocho aos o menos"
                       2         = "Nueve aos"
                       3         = "Diez aos"
                       4         = "Once aos o ms"
                       9         = "Respuesta omitida";
     VALUE edadnF      1         = "Edad normativa"
                       2         = "Extra-edad"
                       9         = "Respuesta omitida";
     VALUE edad_acF    7         = "7 aos"
                       8         = "8 aos"
                       9         = "9 aos"
                       10        = "10 aos"
                       11        = "11 aos"
                       12        = "12 aos"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE mes_nacF    1         = "Enero"
                       2         = "Febrero"
                       3         = "Marzo"
                       4         = "Abril"
                       5         = "Mayo"
                       6         = "Junio"
                       7         = "Julio"
                       8         = "Agosto"
                       9         = "Septiembre"
                       10        = "Octubre"
                       11        = "Noviembre"
                       12        = "Diciembre"
                       98        = "Respuesta mltiple"
                       99        = "Respuesta omitida";
     VALUE docenteF    99999     = "Respuesta omitida";
     VALUE na1_d15F    0         = "Fallo"
                       1         = "Acierto"
                       5         = "Reactivo no alcanzado (se considera como no administrado)"
                       6         = "Reactivo no administrado por error de impresin"
                       7         = "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale03_2010_Alum_CN;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       PNA_01             3
       PNA_02             3
       PNA_03             3
       PNA_04             3
       PNA_05             3
       PNA_06             3
       PNA_07             3
       PNA_08             3
       PNA_10             3
       PNA_11             3
       PNA_12             3
       PNA_13             3
       PNA_15             3
       PNB_01             3
       PNB_02             3
       PNB_03             3
       PNB_04             3
       PNB_05             3
       PNB_06             3
       PNB_07             3
       PNB_08             3
       PNB_09             3
       PNB_10             3
       PNB_11             3
       PNB_12             3
       PNB_13             3
       PNB_14             3
       PNB_15             3
       PNC_01             3
       PNC_03             3
       PNC_04             3
       PNC_05             3
       PNC_06             3
       PNC_08             3
       PNC_09             3
       PNC_10             3
       PNC_11             3
       PNC_12             3
       PNC_13             3
       PNC_14             3
       PND_01             3
       PND_02             3
       PND_03             3
       PND_04             3
       PND_05             3
       PND_06             3
       PND_07             3
       PND_08             3
       PND_09             3
       PND_10             3
       PND_11             3
       PND_13             3
       PND_14             3
       PND_15             3
       PV1CNA             8
       PV2CNA             8
       PV3CNA             8
       PV4CNA             8
       PV5CNA             8
       CNANVL1            3
       CNANVL2            3
       CNANVL3            3
       CNANVL4            3
       CNANVL5            3
       CNANVBL1           3
       CNANVBL2           3
       CNANVBL3           3
       CNANVBL4           3
       CNANVBL5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;








 INFILE alum MISSOVER LINESIZE = 1087;
   INPUT
       NACIONAL             1 - 1
       ESCUELA              2 - 5
       ID_ENT               6 - 7
       NOM_ENT              8 - 26
       ID_MOD              27 - 27
       MOD                 28 - 31
       ESTRATO             32 - 38
       ENTEST              39 - 44
       ALUMNO              45 - 50
       ID_INSTR            51 - 66
       SEXO                67 - 67
       EDAD                68 - 78
       EDADC               79 - 79
       EDADN               80 - 80
       EDAD_AC             81 - 82
       MES_NAC             83 - 84
       W_ALU               85 - 95
       DOCENTE             96 - 100
       PNA_01             101 - 101
       PNA_02             102 - 102
       PNA_03             103 - 103
       PNA_04             104 - 104
       PNA_05             105 - 105
       PNA_06             106 - 106
       PNA_07             107 - 107
       PNA_08             108 - 108
       PNA_10             109 - 109
       PNA_11             110 - 110
       PNA_12             111 - 111
       PNA_13             112 - 112
       PNA_15             113 - 113
       PNB_01             114 - 114
       PNB_02             115 - 115
       PNB_03             116 - 116
       PNB_04             117 - 117
       PNB_05             118 - 118
       PNB_06             119 - 119
       PNB_07             120 - 120
       PNB_08             121 - 121
       PNB_09             122 - 122
       PNB_10             123 - 123
       PNB_11             124 - 124
       PNB_12             125 - 125
       PNB_13             126 - 126
       PNB_14             127 - 127
       PNB_15             128 - 128
       PNC_01             129 - 129
       PNC_03             130 - 130
       PNC_04             131 - 131
       PNC_05             132 - 132
       PNC_06             133 - 133
       PNC_08             134 - 134
       PNC_09             135 - 135
       PNC_10             136 - 136
       PNC_11             137 - 137
       PNC_12             138 - 138
       PNC_13             139 - 139
       PNC_14             140 - 140
       PND_01             141 - 141
       PND_02             142 - 142
       PND_03             143 - 143
       PND_04             144 - 144
       PND_05             145 - 145
       PND_06             146 - 146
       PND_07             147 - 147
       PND_08             148 - 148
       PND_09             149 - 149
       PND_10             150 - 150
       PND_11             151 - 151
       PND_13             152 - 152
       PND_14             153 - 153
       PND_15             154 - 154
       PV1CNA             155 - 162
       PV2CNA             163 - 170
       PV3CNA             171 - 178
       PV4CNA             179 - 186
       PV5CNA             187 - 194
       CNANVL1            195 - 195
       CNANVL2            196 - 196
       CNANVL3            197 - 197
       CNANVL4            198 - 198
       CNANVL5            199 - 199
       CNANVBL1           200 - 200
       CNANVBL2           201 - 201
       CNANVBL3           202 - 202
       CNANVBL4           203 - 203
       CNANVBL5           204 - 204
       WVARSTRR           205 - 207
       W_FSTR1            208 - 218
       W_FSTR2            219 - 229
       W_FSTR3            230 - 240
       W_FSTR4            241 - 251
       W_FSTR5            252 - 262
       W_FSTR6            263 - 273
       W_FSTR7            274 - 284
       W_FSTR8            285 - 295
       W_FSTR9            296 - 306
       W_FSTR10           307 - 317
       W_FSTR11           318 - 328
       W_FSTR12           329 - 339
       W_FSTR13           340 - 350
       W_FSTR14           351 - 361
       W_FSTR15           362 - 372
       W_FSTR16           373 - 383
       W_FSTR17           384 - 394
       W_FSTR18           395 - 405
       W_FSTR19           406 - 416
       W_FSTR20           417 - 427
       W_FSTR21           428 - 438
       W_FSTR22           439 - 449
       W_FSTR23           450 - 460
       W_FSTR24           461 - 471
       W_FSTR25           472 - 482
       W_FSTR26           483 - 493
       W_FSTR27           494 - 504
       W_FSTR28           505 - 515
       W_FSTR29           516 - 526
       W_FSTR30           527 - 537
       W_FSTR31           538 - 548
       W_FSTR32           549 - 559
       W_FSTR33           560 - 570
       W_FSTR34           571 - 581
       W_FSTR35           582 - 592
       W_FSTR36           593 - 603
       W_FSTR37           604 - 614
       W_FSTR38           615 - 625
       W_FSTR39           626 - 636
       W_FSTR40           637 - 647
       W_FSTR41           648 - 658
       W_FSTR42           659 - 669
       W_FSTR43           670 - 680
       W_FSTR44           681 - 691
       W_FSTR45           692 - 702
       W_FSTR46           703 - 713
       W_FSTR47           714 - 724
       W_FSTR48           725 - 735
       W_FSTR49           736 - 746
       W_FSTR50           747 - 757
       W_FSTR51           758 - 768
       W_FSTR52           769 - 779
       W_FSTR53           780 - 790
       W_FSTR54           791 - 801
       W_FSTR55           802 - 812
       W_FSTR56           813 - 823
       W_FSTR57           824 - 834
       W_FSTR58           835 - 845
       W_FSTR59           846 - 856
       W_FSTR60           857 - 867
       W_FSTR61           868 - 878
       W_FSTR62           879 - 889
       W_FSTR63           890 - 900
       W_FSTR64           901 - 911
       W_FSTR65           912 - 922
       W_FSTR66           923 - 933
       W_FSTR67           934 - 944
       W_FSTR68           945 - 955
       W_FSTR69           956 - 966
       W_FSTR70           967 - 977
       W_FSTR71           978 - 988
       W_FSTR72           989 - 999
       W_FSTR73          1000 - 1010
       W_FSTR74          1011 - 1021
       W_FSTR75          1022 - 1032
       W_FSTR76          1033 - 1043
       W_FSTR77          1044 - 1054
       W_FSTR78          1055 - 1065
       W_FSTR79          1066 - 1076
       W_FSTR80          1077 - 1087
 ;









 LABEL
       NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALUMNO      = "Identificador del alumno"
       ID_INSTR    = "Identificador del cuadernillo de examen"
       SEXO        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2010, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2010, codificada (al momento de la aplicacin)"
       EDADN       = "Edad normativa"
       EDAD_AC     = "Edad en aos cumplidos (al momento de la aplicacin)"
       MES_NAC     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       W_ALU       = "Peso muestral o ponderador del alumno"
       DOCENTE     = "Identificador del docente que imparte clases al alumno"
       PNA_01      = "Reactivo 34. Identificar el dibujo que represente el lugar con ms posibilidades de tener aire limpio"
       PNA_02      = "Reactivo 5. Reconocer una accin para cuidar los rboles"
       PNA_03      = "Reactivo 7. Distinguir el tipo de respiracin que tienen algunos animales domsticos"
       PNA_04      = "Reactivo 16. Identificar lo primero que se debe hacer cuando se tiene una herida leve"
       PNA_05      = "Reactivo 15. Identificar un animal carnvoro en una cadena alimentaria"
       PNA_06      = "Reactivo 45. Identificar algunas consecuencias de la ausencia de frutas de la dieta diaria"
       PNA_07      = "Reactivo 49. Reconocer a los seres vivos que producen su propio alimento"
       PNA_08      = "Reactivo 21. Identificar el funcionamiento del sistema locomotor"
       PNA_10      = "Reactivo 38. Identificar uno de los mtodos para purificar el agua"
       PNA_11      = "Reactivo 1. Identificar la trayectoria que describe un objeto en movimiento"
       PNA_12      = "Reactivo 54. Identificar una accin til para cuidar los bosques"
       PNA_13      = "Reactivo 35. Identificar una razn que explique por qu se debe evitar la contaminacin del agua en el ambiente"
       PNA_15      = "Reactivo 53. Reconocer el agua como una va de transmisin de enfermedades del sistema digestivo"
       PNB_01      = "Reactivo 47. Identificar las principales partes de las plantas y sus funciones"
       PNB_02      = "Reactivo 20. Identificar a los organismos descomponedores en una cadena alimentaria"
       PNB_03      = "Reactivo 23. Reconocer cmo funciona el sistema respiratorio"
       PNB_04      = "Reactivo 41. Reconocer una accin para prevenir enfermedades del sistema respiratorio"
       PNB_05      = "Reactivo 51. Identificar el primer eslabn de una cadena alimentaria"
       PNB_06      = "Reactivo 27. Reconocer una recomendacin para mantener sano el sistema circulatorio"
       PNB_07      = "Reactivo 22. Reconocer el movimiento de objetos causado por el viento"
       PNB_08      = "Reactivo 18. Identificar los riesgos de consumir alimentos preparados sin las correctas medidas de higiene"
       PNB_09      = "Reactivo 2. Identificar los cuidados principales para conservar los dientes sanos y en buen estado"
       PNB_10      = "Reactivo 12. Identificar un riesgo para la salud al comer alimentos de escaso valor nutritivo"
       PNB_11      = "Reactivo 33. Reconocer una de las formas en que se usa el agua para el aseo"
       PNB_12      = "Reactivo 44. Clasificar los desechos en orgnicos e inorgnicos"
       PNB_13      = "Reactivo 14. Identificar cundo se forma el vapor en un esquema del ciclo del agua"
       PNB_14      = "Reactivo 36. Identificar una planta cuya raz sirva de alimento a los seres humanos"
       PNB_15      = "Reactivo 19. Identificar una forma de ahorrar agua"
       PNC_01      = "Reactivo 17. Reconocer que el aire es indispensable para la vida"
       PNC_03      = "Reactivo 43. Reconocer el proceso de formacin de un fruto"
       PNC_04      = "Reactivo 8. Reconocer trayectorias recta, curva y circular"
       PNC_05      = "Reactivo 30. Reconocer que el agua es indispensable para los seres vivos"
       PNC_06      = "Reactivo 46. Reconocer una planta medicinal"
       PNC_08      = "Reactivo 6. Identificar grupos de alimentos ricos en vitaminas y minerales"
       PNC_09      = "Reactivo 11. Reconocer los riesgos que se tienen al beber agua que no es potable"
       PNC_10      = "Reactivo 4. Identificar una accin en la que se reutilicen desechos"
       PNC_11      = "Reactivo 26. Distinguir una actividad en la que el movimiento del corazn es acelerado"
       PNC_12      = "Reactivo 13. Identificar medidas para disminuir riesgos de daos en el hogar"
       PNC_13      = "Reactivo 40. Identificar recursos naturales renovables y no renovables"
       PNC_14      = "Reactivo 48. Identificar un producto a partir de algunos elementos de su proceso de elaboracin"
       PND_01      = "Reactivo 3. Identificar una planta que sirve de alimento a los seres humanos"
       PND_02      = "Reactivo 37. Relacionar un recurso natural con el producto que se obtiene de l"
       PND_03      = "Reactivo 31. Identificar una de las acciones humanas que contaminan el aire"
       PND_04      = "Reactivo 52. Reconocer la transformacin que tienen los alimentos al pasar por el sistema digestivo"
       PND_05      = "Reactivo 25. Identificar una consecuencia de la eliminacin de algn eslabn de una cadena alimentaria"
       PND_06      = "Reactivo 32. Distinguir un alimento que tenga un alto valor nutritivo"
       PND_07      = "Reactivo 29. Reconocer una forma de evidenciar la presencia del aire"
       PND_08      = "Reactivo 9. Identificar un ser vivo que respira por medio de branquias"
       PND_09      = "Reactivo 42. Identificar el funcionamiento del sistema circulatorio"
       PND_10      = "Reactivo 28. Identificar lugares de riesgo de accidentes en el hogar, la escuela y la comunidad"
       PND_11      = "Reactivo 24. Reconocer que tirar basura en los ros y lagos puede ocasionar enfermedades a las personas"
       PND_13      = "Reactivo 10. Reconocer algunos sntomas de las enfermedades ms frecuentes del sistema digestivo"
       PND_14      = "Reactivo 50. Identificar las ventajas de cocer los alimentos"
       PND_15      = "Reactivo 39. Reconocer la fuerza que se requiere para mover un objeto"
       PV1CNA      = "Primer valor plausible de Ciencias Naturales"
       PV2CNA      = "Segundo valor plausible de Ciencias Naturales"
       PV3CNA      = "Tercer valor plausible de Ciencias Naturales"
       PV4CNA      = "Cuarto valor plausible de Ciencias Naturales"
       PV5CNA      = "Quinto valor plausible de Ciencias Naturales"
       CNANVL1     = "Nivel de logro en Ciencias Naturales. Asociado a PV1CNA. (Cuatro niveles)"
       CNANVL2     = "Nivel de logro en Ciencias Naturales. Asociado a PV2CNA. (Cuatro niveles)"
       CNANVL3     = "Nivel de logro en Ciencias Naturales. Asociado a PV3CNA. (Cuatro niveles)"
       CNANVL4     = "Nivel de logro en Ciencias Naturales. Asociado a PV4CNA. (Cuatro niveles)"
       CNANVL5     = "Nivel de logro en Ciencias Naturales. Asociado a PV5CNA. (Cuatro niveles)"
       CNANVBL1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV1CNA."
       CNANVBL2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV2CNA."
       CNANVBL3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV3CNA."
       CNANVBL4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV4CNA."
       CNANVBL5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV5CNA."
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;




 FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       PNA_01             na1_d15F.
       PNA_02             na1_d15F.
       PNA_03             na1_d15F.
       PNA_04             na1_d15F.
       PNA_05             na1_d15F.
       PNA_06             na1_d15F.
       PNA_07             na1_d15F.
       PNA_08             na1_d15F.
       PNA_10             na1_d15F.
       PNA_11             na1_d15F.
       PNA_12             na1_d15F.
       PNA_13             na1_d15F.
       PNA_15             na1_d15F.
       PNB_01             na1_d15F.
       PNB_02             na1_d15F.
       PNB_03             na1_d15F.
       PNB_04             na1_d15F.
       PNB_05             na1_d15F.
       PNB_06             na1_d15F.
       PNB_07             na1_d15F.
       PNB_08             na1_d15F.
       PNB_09             na1_d15F.
       PNB_10             na1_d15F.
       PNB_11             na1_d15F.
       PNB_12             na1_d15F.
       PNB_13             na1_d15F.
       PNB_14             na1_d15F.
       PNB_15             na1_d15F.
       PNC_01             na1_d15F.
       PNC_03             na1_d15F.
       PNC_04             na1_d15F.
       PNC_05             na1_d15F.
       PNC_06             na1_d15F.
       PNC_08             na1_d15F.
       PNC_09             na1_d15F.
       PNC_10             na1_d15F.
       PNC_11             na1_d15F.
       PNC_12             na1_d15F.
       PNC_13             na1_d15F.
       PNC_14             na1_d15F.
       PND_01             na1_d15F.
       PND_02             na1_d15F.
       PND_03             na1_d15F.
       PND_04             na1_d15F.
       PND_05             na1_d15F.
       PND_06             na1_d15F.
       PND_07             na1_d15F.
       PND_08             na1_d15F.
       PND_09             na1_d15F.
       PND_10             na1_d15F.
       PND_11             na1_d15F.
       PND_13             na1_d15F.
       PND_14             na1_d15F.
       PND_15             na1_d15F.
;






/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;


   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;


   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;


   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(54)
                  PNA_01 PNA_02 PNA_03 PNA_04 PNA_05 PNA_06 PNA_07 PNA_08 PNA_10
                  PNA_11 PNA_12 PNA_13 PNA_15 PNB_01 PNB_02 PNB_03 PNB_04 PNB_05
                  PNB_06 PNB_07 PNB_08 PNB_09 PNB_10 PNB_11 PNB_12 PNB_13 PNB_14
                  PNB_15 PNC_01 PNC_03 PNC_04 PNC_05 PNC_06 PNC_08 PNC_09 PNC_10
                  PNC_11 PNC_12 PNC_13 PNC_14 PND_01 PND_02 PND_03 PND_04 PND_05
                  PND_06 PND_07 PND_08 PND_09 PND_10 PND_11 PND_13 PND_14 PND_15;

   DO  i=1 TO 54;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
